@@ -10,7 +10,7 @@ use Digest::SHA ();
 our @CARP_NOT = qw( alienfile Alien::Build Alien::Build::Meta );
 
 # ABSTRACT: Plugin base class for Alien::Build
-our $VERSION = '2.48'; # VERSION
+our $VERSION = '2.76'; # VERSION
 
 
 sub new
@@ -68,19 +68,6 @@ sub import
 }
 
 
-sub subplugin
-{
-  my(undef, $name, %args) = @_;
-  Carp::carp("subplugin method is deprecated");
-  my $class = "Alien::Build::Plugin::$name";
-  my $pm = "$class.pm";
-  $pm =~ s/::/\//g;
-  require $pm unless eval { $class->can('new') };
-  delete $args{$_} for grep { ! defined $args{$_} } keys %args;
-  $class->new(%args);
-}
-
-
 my %meta;
 sub meta
 {
@@ -146,7 +133,7 @@ Alien::Build::Plugin - Plugin base class for Alien::Build
 
 =head1 VERSION
 
-version 2.48
+version 2.76
 
 =head1 SYNOPSIS
 
@@ -199,14 +186,18 @@ Tools for building.
 
 Tools already included.
 
-=item L<Alien::Build::Plugin::Download>
-
-Methods for retrieving from the internet.
-
 =item L<Alien::Build::Plugin::Decode>
 
 Normally use Download plugins which will pick the correct Decode plugins.
 
+=item L<Alien::Build::Plugin::Digest>
+
+Tools for checking cryptographic signatures during a C<share> install.
+
+=item L<Alien::Build::Plugin::Download>
+
+Methods for retrieving from the internet.
+
 =item L<Alien::Build::Plugin::Extract>
 
 Extract from archives that have been downloaded.
@@ -215,6 +206,15 @@ Extract from archives that have been downloaded.
 
 Normally use Download plugins which will pick the correct Fetch plugins.
 
+=item L<Alien::Build::Plugin::Gather>
+
+Plugins that modify or enhance the gather step.
+
+=item L<Alien::Build::Plugin::PkgConfig>
+
+Plugins that work with C<pkg-config> or libraries that provide the same
+functionality.
+
 =item L<Alien::Build::Plugin::Prefer>
 
 Normally use Download plugins which will pick the correct Prefer plugins.
@@ -223,6 +223,10 @@ Normally use Download plugins which will pick the correct Prefer plugins.
 
 Look for packages already installed on the system.
 
+=item L<Alien::Build::Plugin::Probe>
+
+Plugins useful for unit testing L<Alien::Build> itself, or plugins for it.
+
 =back
 
 =head1 CONSTRUCTOR
@@ -251,27 +255,6 @@ in practice you should never have two instances with the exact same arguments.
 You provide the implementation for this.  The intent is to register
 hooks and set meta properties on the L<Alien::Build> class.
 
-=head2 subplugin
-
-B<DEPRECATED>: Maybe removed, but not before 1 October 2018.
-
- my $plugin2 = $plugin1->subplugin($plugin_name, %args);
-
-Finds the given plugin and loads it (unless already loaded) and creats a
-new instance and returns it.  Most useful from a Negotiate plugin,
-like this:
-
- sub init
- {
-   my($self, $meta) = @_;
-   $self->subplugin(
-     'Foo::Bar',  # loads Alien::Build::Plugin::Foo::Bar,
-                  # or throw exception
-     foo => 1,    # these key/value pairs passsed into new
-     bar => 2,    # for the plugin instance.
-   )->init($meta);
- }
-
 =head2 has
 
  has $prop_name;
@@ -356,9 +339,11 @@ Håkon Hægland (hakonhagland, HAKONH)
 
 nick nauwelaerts (INPHOBIA)
 
+Florian Weimer
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2011-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
